#
# spec file for package ghc-semigroupoids
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name semigroupoids
Name:           ghc-%{pkg_name}
Version:        5.3.7
Release:        bp155.2.15
Summary:        Semigroupoids: Category sans id
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-orphans-devel
BuildRequires:  ghc-bifunctors-devel
BuildRequires:  ghc-comonad-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-contravariant-devel
BuildRequires:  ghc-distributive-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unordered-containers-devel
ExcludeArch:    %{ix86}

%description
Provides a wide array of (semi)groupoids and operations for working with them.

A 'Semigroupoid' is a 'Category' without the requirement of identity arrows for
every object in the category.

A 'Category' is any 'Semigroupoid' for which the Yoneda lemma holds.

When working with comonads you often have the '<*>' portion of an
'Applicative', but not the 'pure'. This was captured in Uustalu and Vene's
"Essence of Dataflow Programming" in the form of the 'ComonadZip' class in the
days before 'Applicative'. Apply provides a weaker invariant, but for the
comonads used for data flow programming (found in the streams package), this
invariant is preserved. Applicative function composition forms a semigroupoid.

Similarly many structures are nearly a comonad, but not quite, for instance
lists provide a reasonable 'extend' operation in the form of 'tails', but do
not always contain a value.

We describe the relationships between the type classes defined in this package
and those from `base` (and some from `contravariant`) in the diagram below.
Thick-bordered nodes correspond to type classes defined in this package;
thin-bordered ones correspond to type classes from elsewhere. Solid edges
indicate a subclass relationship that actually exists; dashed edges indicate a
subclass relationship that /should/ exist, but currently doesn't.

<<https://raw.githubusercontent.com/ekmett/semigroupoids/master/img/classes.svg
Relationships among type classes from this package and others>>

Apply, Bind, and Extend (not shown) give rise the Static, Kleisli and Cokleisli
semigroupoids respectively.

This lets us remove many of the restrictions from various monad transformers as
in many cases the binding operation or '<*>' operation does not require them.

Finally, to work with these weaker structures it is beneficial to have
containers that can provide stronger guarantees about their contents, so
versions of 'Traversable' and 'Foldable' that can be folded with just a
'Semigroup' are added.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown

%changelog
* Mon Jan 10 2022 Peter Simons <psimons@suse.com>
- Update semigroupoids to version 5.3.7.
  5.3.7 [2022.01.09]
  - -----------------
  * Relax the `Bind` constraints in the following instances to `Functor`:
    ```diff
  - instance (Bind f,    Monad f) => Alt  (MaybeT f)
  - instance (Bind f,    Monad f) => Plus (MaybeT f)
    +instance (Functor f, Monad f) => Alt  (MaybeT f)
    +instance (Functor f, Monad f) => Plus (MaybeT f)
  - instance (Bind f,    Monad f, Semigroup e)           => Alt  (ExceptT e f)
  - instance (Bind f,    Monad f, Semigroup e, Monoid e) => Plus (ExceptT e f)
    +instance (Functor f, Monad f, Semigroup e)           => Alt  (ExceptT e f)
    +instance (Functor f, Monad f, Semigroup e, Monoid e) => Plus (ExceptT e f)
  - - If building with transformers-0.5.* or older
  - instance (Bind f,    Monad f)          => Alt  (ErrorT e f)
  - instance (Bind f,    Monad f, Error e) => Plus (ErrorT e f
    +instance (Functor f, Monad f)          => Alt  (ErrorT e f)
    +instance (Functor f, Monad f, Error e) => Plus (ErrorT e f)
    ```
* Wed Nov 10 2021 psimons@suse.com
- Update semigroupoids to version 5.3.6 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Oct 10 2021 psimons@suse.com
- Update semigroupoids to version 5.3.6 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Oct  8 2021 psimons@suse.com
- Update semigroupoids to version 5.3.6.
  5.3.6 [2021.10.07]
  - -----------------
  * Allow building with GHC 9.2.
  * Allow building with `transformers-0.6.*`.
  * Add `Alt` instance for `Identity`.
  * Add `Conclude`, `Decide` and `Divise` type classes and instances.
  * Add `(<.*>)`, `(<*.>)`, and `traverseMaybe` functions, which make it easier
    to defined `Traversable1` instances for data types that have fields with a
    combination of `Traversable` and `Traversable1` instances.
  * Add `Semigroupoids.Do` module with overloads for use with `QualifiedDo`.
  * Add `Apply`, `Alt`, `Plus`, `Bind` and `BindTrans` instances for the CPS
    versions of `WriterT` and `RWST`.
  * Add `psum` function to `Data.Functor.Plus`.
  * Add `Categorical` data type.
* Tue Jul 27 2021 psimons@suse.com
- Update semigroupoids to version 5.3.5 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Jan  4 2021 psimons@suse.com
- Update semigroupoids to version 5.3.5.
  5.3.5 [2020.12.31]
  - -----------------
  * The build-type has been changed from `Custom` to `Simple`.
    To achieve this, the `doctests` test suite has been removed in favor of using
    [`cabal-docspec`](https://github.com/phadej/cabal-extras/tree/master/cabal-docspec)
    to run the doctests.
  * Explicitly mark modules as `Safe`.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Oct  6 2020 psimons@suse.com
- Update semigroupoids to version 5.3.4 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Aug 31 2020 psimons@suse.com
- Update semigroupoids to version 5.3.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed Nov 27 2019 psimons@suse.com
- Update semigroupoids to version 5.3.4.
  5.3.4 [2019.11.26]
  - -----------------
  * Achieve forward compatibility with
    [GHC proposal 229](https://github.com/ghc-proposals/ghc-proposals/blob/master/proposals/0229-whitespace-bang-patterns.rst).
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Wed Aug 28 2019 psimons@suse.com
- Update semigroupoids to version 5.3.3.
  5.3.3 [2019.08.27]
  - -----------------
  * Add `Alt` and `Plus` instances for `HashMap` from the `unordered-containers`
    package.
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Sat Jan  5 2019 psimons@suse.com
- Update semigroupoids to version 5.3.2.
  5.3.2 [2019.01.04]
  - -----------------
  * Bump the lower bound on `semigroups` to 0.16.2, and avoid incurring
    the dependency entirely on recent GHCs.
  * Fix the build on GHC 7.0 and 7.2.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update semigroupoids to version 5.3.1.
  * Fix a regression introduced in `semigroupoids-5.3` in which some modules
    regressed from `Trustworthy` to `Unsafe`.
  * Allow building with `containers-0.6`.
  * Add `Alt` instances for `First` and `Last` from `Data.Semigroup`, and
    `Alt` and `Plus` instances for `First` and `Last` from `Data.Monoid`.
  * Add missing `Apply`, `Bind`, `Extend`, `Foldable1` and `Traversable1`
    instances for `Data.Semigroups`, `Data.Monoid` and `GHC.Generics`.
* Mon May 14 2018 psimons@suse.com
- Update semigroupoids to version 5.2.2 revision 3.
  * Add `optional` to `Data.Functor.Alt` (analogous to the `optional` function
    in `Control.Applicative`)
  * `liftF2` is now a class method of `Apply` (mirroring the fact that `liftA2`
    is now a class method of `Applicative`). `liftF2` and `(<.>)` have default
    definitions in terms of the other.
  * Allow building with GHC 8.4
  * `Apply` and `Bind` instances for `Q`, from the `template-haskell` package.
  * Add instances for `(:~:)` and `(:~~:)` from `Data.Type.Equality`, and
    `Coercion` from `Data.Type.Coercion`
  * Add the `toNonEmpty` method to `Foldable1`. Add `foldrM1` and `foldlM1`
    functions to `Data.Semigroup.Foldable` that are defined in terms of `toNonEmpty`.
  * Add `Apply`, `Bind`, `Foldable1`, and `Traversable1` instances for `Complex`
  * Add `Apply` and `Bind` instances for `HashMap` from the `unordered-containers` package
    (on which `semigroupoids` now depends)
  * Add `Semigroupoid` instances for `Tagged` and `Const`
* Thu Jul 27 2017 psimons@suse.com
- Update to version 5.2.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 5.1 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 5.0.1 revision 1 with cabal2obs.
* Mon Jan 18 2016 mimi.vx@gmail.com
- update to 5.0.1
  * transformers-compat 0.5 support
  * Removed some redundant constraints.
* Sun Aug 23 2015 mimi.vx@gmail.com
- update to 5.0.0.4
  * doctest 0.10 support
* Thu Aug 13 2015 mimi.vx@gmail.com
- update to 5.0.0.3
* Thu Aug  6 2015 mimi.vx@gmail.com
- update to 5.0.0.2
  * Added the CHANGELOG to the distribution so that hackage can link to it in the haddocks.
  * Absorbed Data.Bifunctor.Apply, Data.Semigroup.Bifoldable and Data.Semigroup.Traversable
  from bifunctors.
  * This caused us to pick up a dependency on tagged.
  * Exiled Data.Semifunctor.*, Data.Semigroupoid.Product and Data.Semigroupoid.Coproduct
  to semigroupoid-extras.
  * Set an explicit fixity for -<- and ->-.
  * Major changes to the API to support PolyKinds and DataKinds. This necessarily shuts off GHC <= 7.4.
  * Orphan instances have moved upstream into a common base-orphans package.
  * Added asum1 to Data.Semigroup.Foldable.
  * Support for 'ConstrainedClassMethods' is currently required for GHC HEAD.
* Wed May 27 2015 mimi.vx@gmail.com
- correct license to BSD-2-Clause
* Sun Apr 26 2015 mimi.vx@gmail.com
- initial commit
